@@ -64,12 +64,20 @@ void Audio::threadFinished()
 
     connect(music, SIGNAL(finished()), this, SLOT(audioFinished()));
 
-    audioFile->close();
     this->wavCreated();
 
  //   reader->deleteLater();
 }
 
+void Audio::setAudio(QString filename)
+{
+    music = Phonon::createPlayer(Phonon::MusicCategory,
+                                 Phonon::MediaSource(filename));
+
+
+    connect(music, SIGNAL(finished()), this, SLOT(audioFinished()));
+}
+
 void Audio::audioFinished()
 {
     this->finished();
