@@ -63,9 +63,12 @@ void Player::openArticle(QString itemName, QString text, bool playlist)
 
 
     ui->articleBrowser->setText(text);
+    bool audioExists = QFile(QDesktopServices::storageLocation(QDesktopServices::DocumentsLocation) +  itemName.toLower().normalized(QString::NormalizationForm_D).replace(" ", "_")+".wav").exists();
 
-    if (!playlist)
+    if (!playlist || !audioExists)
         audio->createWav(path);
+    if (audioExists)
+        audio->setAudio(QDesktopServices::storageLocation(QDesktopServices::DocumentsLocation) +  itemName.toLower().normalized(QString::NormalizationForm_D).replace(" ", "_")+".wav");
 
     articleLoaded = true;
 
@@ -115,7 +118,7 @@ void Player::on_forwardButton_clicked()
 void Player::setPlaylistFocus()
 {
     reload = true;
-    this->ui->playListWidget->setCurrentRow(0, QItemSelectionModel::Select);
+    this->ui->playListWidget->setCurrentRow(1, QItemSelectionModel::Select);
 
     this->openArticleFromLink(ui->playListWidget->item(this->ui->playListWidget->currentRow()));
     audio->createWav(this->ui->playListWidget->currentItem()->text());
