@@ -5,6 +5,7 @@
 #include <QTreeWidgetItem>
 #include <playlists.h>
 #include <QDialogButtonBox>
+#include <QDialog>
 
 namespace Ui {
     class Playlist;
@@ -36,7 +37,7 @@ private:
     QMap<QString, QString> *titles;
     Playlists *playlistlist;
     void updateList();
-    QDialogButtonBox *box;
+  //  QDialog *box;
     QTreeWidgetItem *clickedItem;
     int clickedColumn;
 
