@@ -15,6 +15,8 @@ Playlists::Playlists()
     }
     else
         qDebug()<<"file error";
+
+
 }
 
 QStringList Playlists::getPlaylistContent(QString title)
@@ -53,23 +55,38 @@ void Playlists::addNewItemToPlaylist(QString title, QString item)
 
 void Playlists::removePlaylistItem(QString item, int column, QTreeWidgetItem *parent)
 {
-    QStringList items;
-    items = playlists.take(parent->text(column));
-    if (items.contains(item))
+    if (playlists.keys().contains(item))
     {
-
-        items.removeOne(item);
-
-    }
-    playlists.insert(parent->text(column), items);
-    if (playlistFile->open(QIODevice::WriteOnly))
-    {
-        QDataStream out(playlistFile);   // we will serialize the data into the file
-        out << this->playlists;
-        playlistFile->close();
+        playlists.remove(item);
+        if (playlistFile->open(QIODevice::WriteOnly))
+        {
+            QDataStream out(playlistFile);   // we will serialize the data into the file
+            out << this->playlists;
+            playlistFile->close();
+        }
+        else
+            qDebug()<<"write error";
     }
     else
-        qDebug()<<"write error";
+    {
+        QStringList items;
+        items = playlists.take(parent->text(column));
+        if (items.contains(item))
+        {
+
+            items.removeOne(item);
+
+        }
+        playlists.insert(parent->text(column), items);
+        if (playlistFile->open(QIODevice::WriteOnly))
+        {
+            QDataStream out(playlistFile);   // we will serialize the data into the file
+            out << this->playlists;
+            playlistFile->close();
+        }
+        else
+            qDebug()<<"write error";
+    }
 
 }
 
