@@ -22,13 +22,8 @@ void Reader::run()
         myProcess->start(program, arguments);
         myProcess->waitForFinished();
 
-        music = Phonon::createPlayer(Phonon::MusicCategory,
-                                      Phonon::MediaSource(audioFile->fileName()));
-
-
-        connect(music, SIGNAL(finished()), this, SLOT(audioFinished()));
-
         audioFile->close();
+        this->finished();
 
     }
 }
